PCB Environment: py::ObjectRef Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
py::ObjectRef Class Reference

## Public Member Functions
| ObjectRef (PyObject *, uint refs=0)
void | reset (PyObject *, uint refs=0)
const Object * | operator-> () const
const Object & | operator* () const
PyObject * | getRef () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/PyObject.hpp